Stan Math Library: stan/math/rev/arr/functor/coupled_ode_system.hpp File Reference

| Stan Math Library 2.10.0 reverse mode automatic differentiation

- Main Page
- Modules
- Namespaces
- Classes
- Files

- File List
- File Members

Classes | Namespaces | Functions
coupled_ode_system.hpp File Reference
`#include <stan/math/prim/arr/meta/get.hpp>`
`#include <stan/math/prim/arr/meta/length.hpp>`
`#include <stan/math/prim/scal/err/check_equal.hpp>`
`#include <stan/math/prim/arr/functor/coupled_ode_system.hpp>`
`#include <stan/math/rev/scal/fun/value_of_rec.hpp>`
`#include <stan/math/rev/scal/fun/value_of.hpp>`
`#include <stan/math/rev/core.hpp>`
`#include <ostream>`
`#include <stdexcept>`
`#include <vector>`

Go to the source code of this file.

## Classes
struct | stan::math::coupled_ode_system< F, double, stan::math::var >
| The coupled ODE system for known initial values and unknown parameters. More...
struct | stan::math::coupled_ode_system< F, stan::math::var, double >
| The coupled ODE system for unknown initial values and known parameters. More...
struct | stan::math::coupled_ode_system< F, stan::math::var, stan::math::var >
| The coupled ode system for unknown intial values and unknown parameters. More...

## Namespaces
| stan
| stan::math
| Matrices and templated mathematical functions.

## Functions
void | stan::math::add_initial_values (const std::vector< stan::math::var > &y0, std::vector< std::vector< stan::math::var > > &y)
| Increment the state derived from the coupled system in the with the original initial state. More...

[ Stan Home Page ] © 2011–2016, Stan Development Team.